---
title: <span class="badge builder"></span> GeoHashGridSettings
---
# <span class="badge builder"></span> GeoHashGridSettings

## Constructor

```python
GeoHashGridSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.GeoHashGridSettings
```

### <span class="badge object-method"></span> precision

```python
def precision(precision: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [GeoHashGridSettings](./object-GeoHashGridSettings.md)
